--
-- Filename: editNoteEvent.lua
-- Author: Martin Fabík (LoogleCZ)
--
-- This event is part of NotesMod.
--

editNoteEvent = {};
editNoteEvent_mt = Class(editNoteEvent, Event);

InitEventClass(editNoteEvent, "editNoteEvent");

function editNoteEvent:emptyNew()
    local self = Event:new(editNoteEvent_mt);
    return self;
end;

function editNoteEvent:new(noteIndex,note)
    local self = editNoteEvent:emptyNew();
	self.noteIndex = noteIndex;
	self.note = note;
    return self;
end;

function editNoteEvent:readStream(streamId, connection)
	self.noteIndex = streamReadInt16(streamId);
	self.note = {};
	self.note.name = streamReadString(streamId);
	self.note.content = streamReadString(streamId);
	self.note.author = streamReadString(streamId);
	self:run(connection);
end;

function editNoteEvent:writeStream(streamId, connection)
	streamWriteInt16(streamId, self.noteIndex);
	if self.note.name == nil then
		streamWriteString(streamId, "");
	else
		streamWriteString(streamId, self.note.name);
	end;
	if self.note.content == nil then
		streamWriteString(streamId, "");
	else
		streamWriteString(streamId, self.note.content);
	end;
	streamWriteString(streamId, self.note.author);
end;

function editNoteEvent:run(connection)
	g_currentMission.NotesBase.notes[self.noteIndex] = self.note;
	if g_currentMission.NotesBase.isClient then
		g_currentMission.NotesBase.itemList.elements[self.noteIndex].elements = {};
		Notes:drawNote(self.note,g_currentMission.NotesBase.itemList.elements[self.noteIndex]);
		if g_currentMission.NotesBase.selectedIndex ~= nil then
			if g_currentMission.NotesBase.selectedIndex == self.noteIndex then
				-- edituju a někdo změnil (editoval taky)
				--
				-- nebo mám selectnuté a někdo změnil
				Notes:selectNote(self.noteIndex);
			end;
		end;
	end;
	if not connection:getIsServer() then
		g_server:broadcastEvent(editNoteEvent:new(self.noteIndex,self.note));
	end;
end;

function editNoteEvent:sendEvent(noteIndex,name,content,author)
	local note = {};
	note.name = name;
	note.content = content;
	note.author = author;
	if g_server ~= nil then
		g_currentMission.NotesBase.notes[noteIndex] = note;
		if g_currentMission.NotesBase.isClient then
			g_currentMission.NotesBase.itemList.elements[noteIndex].elements = {};
			Notes:drawNote(note,g_currentMission.NotesBase.itemList.elements[noteIndex]);
		end;
		g_server:broadcastEvent(editNoteEvent:new(noteIndex,note));
	else
		g_client:getServerConnection():sendEvent(editNoteEvent:new(noteIndex,note));
	end;
end;
