--
-- Filename: rafftnixGUI_FIX.lua
-- Author: Martin Fabík (LoogleCZ)
-- 
-- This script changes default definition of some rafftnix's functions.
-- This script is part of NotesMod.
--

function RafftnixGUI:close()
	self.baseElement.visibility = false;
	if self.fullScreenMode then
		InputBinding.setShowMouseCursor(false);
		g_currentMission.isPlayerFrozen = false;
		g_gui.currentGui = nil;
		g_gui.currentGuiName = "";
	end;
	if self.mouseActive then
		InputBinding.setShowMouseCursor(false);
	end;
end;

function RafftnixGUI:createList(baseElement, posX, posY, width, height, heightPerEntry, maxVisibleEntrys, selectEntryCallbackFunction, selectEntryCallbackTarget, markSelectedItem, scrollSettings)
	local element = self:createElement(baseElement, posX, posY, width, height);
	
	element.isList = true;
	element.isPrewInactive = false;
	element.isNextInactive = false;
	element.maxVisibleEntrys = maxVisibleEntrys;
	element.selectedEntry = 1;
	element.highestVisibleEntry = 1;
	element.heightPerEntry = heightPerEntry;
	element.selectEntryCallbackFunction = selectEntryCallbackFunction;
	element.selectEntryCallbackTarget = selectEntryCallbackTarget;
	element.markSelectedItem = Utils.getNoNil(markSelectedItem, false);
	element.scrollSettings = scrollSettings;
	
	function element:scrollUp()
		element.highestVisibleEntry = math.max(1, element.highestVisibleEntry-1);
		element:checkScrollButtons();
	end;
	
	function element:scrollDown()
		element.highestVisibleEntry = math.max(1, math.min(table.getn(element.elements) - element.maxVisibleEntrys + 1, element.highestVisibleEntry+1));
		element:checkScrollButtons();
	end;
	
	function element:setHighestVisibleEntry(index)
		element.highestVisibleEntry = math.max(1, math.min(table.getn(element.elements) - element.maxVisibleEntrys + 1, index));
		element:checkScrollButtons();
	end;
	
	function element:checkScrollButtons()
		if element.scrollSettings ~= nil then
			if element.isNextInactive and not (element.highestVisibleEntry == table.getn(element.elements) - element.maxVisibleEntrys + 1 or table.getn(element.elements) < element.maxVisibleEntrys) then
				element.isNextInactive = false;
				local k = element.scrollSettings.nextA.overlayId;
				element.scrollSettings.nextA.overlayId = element.scrollSettings.nextA.inactiveOverlayId;
				element.scrollSettings.nextA.inactiveOverlayId = k;
				element.scrollSettings.nextA.mouseOverOverlayId = element.scrollSettings.nextA.oldMouseOverOverlayId;
			end;
			if element.isPrewInactive and not (element.highestVisibleEntry == 1) then
				element.isPrewInactive = false;
				local k = element.scrollSettings.prewiousA.overlayId;
				element.scrollSettings.prewiousA.overlayId = element.scrollSettings.prewiousA.inactiveOverlayId;
				element.scrollSettings.prewiousA.inactiveOverlayId = k;
				element.scrollSettings.prewiousA.mouseOverOverlayId = element.scrollSettings.prewiousA.oldMouseOverOverlayId;
			end;
			if element.highestVisibleEntry == 1 and not element.isPrewInactive then
				element.isPrewInactive = true;
				local k = element.scrollSettings.prewiousA.overlayId;
				element.scrollSettings.prewiousA.overlayId = element.scrollSettings.prewiousA.inactiveOverlayId;
				element.scrollSettings.prewiousA.inactiveOverlayId = k;
				element.scrollSettings.prewiousA.oldMouseOverOverlayId = element.scrollSettings.prewiousA.mouseOverOverlayId;
				element.scrollSettings.prewiousA.mouseOverOverlayId = nil;
			end;
			if (element.highestVisibleEntry == table.getn(element.elements) - element.maxVisibleEntrys + 1 or table.getn(element.elements) < element.maxVisibleEntrys) and not element.isNextInactive then
				element.isNextInactive = true;
				local k = element.scrollSettings.nextA.overlayId;
				element.scrollSettings.nextA.overlayId = element.scrollSettings.nextA.inactiveOverlayId;
				element.scrollSettings.nextA.inactiveOverlayId = k;
				element.scrollSettings.nextA.oldMouseOverOverlayId = element.scrollSettings.nextA.mouseOverOverlayId;
				element.scrollSettings.nextA.mouseOverOverlayId = nil;
			end;
		end;
	end;
	
	return element;
end;

function RafftnixGUI:renderElement(element, x, y, scaleX, scaleY, parentElementSelected)
	scaleX = scaleX * element.scaleX;
	scaleY = scaleY * element.scaleY;

	local textScale = math.min(scaleX, scaleY);

	if element.visibility then
		x = x + element.posX*scaleX;
		y = y + element.posY*scaleY;

		if element.text ~= nil then
			if element.markSelectedItem and (element.isSelected or parentElementSelected) then
				setTextColor(0,1,0,element.textColor[4]);
			else
				setTextColor(unpack(element.textColor));
			end;
			setTextAlignment(RenderText.ALIGN_LEFT);
			
			local textX = 0;
			local textY = 0;
			
			if element.textFocusX == "left" then
				textX = x;
			elseif element.textFocusX == "middle" then
				textX = x + 0.5*(element.width*scaleX) - 0.5*getTextWidth(element.textSize*textScale, element.text);
			elseif element.textFocusX == "right" then
				textX = x + (element.width*scaleX) - getTextWidth(element.textSize*textScale, element.text);
			end;
			
			if element.textFocusY == "top" then
				textY = y + element.height*scaleY - getTextHeight(element.textSize*textScale, element.text);
			elseif element.textFocusY == "center" then
				textY = y + 0.5*(element.height*scaleY) - 0.5*getTextHeight(element.textSize*textScale, element.text);
			elseif element.textFocusY == "bottom" then
				textY = y;
			end;
			if element.isBold ~= nil and element.isBold then
				setTextBold(true);
			end;
			renderText(textX, textY, element.textSize*textScale, element.text);
			setTextColor(1, 1, 1, 1);
			setTextBold(false);
		end;
		if element.overlayId ~= nil then 
			renderOverlay(element.overlayId, x, y, element.width*scaleX, element.height*scaleY);
		end;
		
		if element.isList ~= nil then -- list
			local start = element.highestVisibleEntry;
			local stop = math.min(element.highestVisibleEntry + element.maxVisibleEntrys - 1, table.getn(element.elements));
			y = element.posY + element.height;
			
			for a=start, stop do
				if element.elements[a] ~= nil then
					y = y - element.heightPerEntry;
					
					local parentElementSelected = false;
					if element.selectedEntry == a then
						parentElementSelected = true;
					end;
					self:renderElement(element.elements[a], x, y, scaleX, scaleY, parentElementSelected);
				end;
			end;
		else
			for a=1, table.getn(element.elements) do
				self:renderElement(element.elements[a], x, y, scaleX, scaleY, parentElementSelected);
			end;
		end;
		if element.mouseOverOverlayId ~= nil and (element.mouseOver or element.isSelected) then
			renderOverlay(element.mouseOverOverlayId, x, y, element.width*scaleX, element.height*scaleY);
		end;
	end;
end;
